use uuid::Uuid;
use crate::{components::{CompGetter, CompUi}, windows::WindowId};


#[derive(Debug, Default)]
pub struct Header {
    pub search_text: String,
}

component_register!(Header);

impl CompUi for Header {
    fn draw(ui: &mut egui::Ui, state: &mut crate::GuiState) -> crate::Result<()> {
        let theme = xmpd_settings::Settings::get()?.theme.clone();

        ui.vertical(|ui| {
            ui.horizontal(|ui| {
                let search_icon = egui::Image::new(crate::data::SEARCH_ICON)
                    .fit_to_exact_size(egui::Vec2::new(16.0, 16.0))
                    .tint(theme.accent_color);
                ui.add(search_icon);
                {
                    ui.text_edit_singleline(&mut handle_error_ui!(Header::get()).search_text);
                }
            });
            //ui.with_layout(egui::Layout::top_down(egui::Align::), add_contents)
            ui.with_layout(egui::Layout::right_to_left(egui::Align::Min), |ui| {
                let add_song = ui.add(
                    egui::Image::new(crate::data::PLUS_ICON)
                        .tint(theme.accent_color)
                        .sense(egui::Sense::click())
                        .fit_to_exact_size(egui::Vec2::new(16.0, 16.0))
                );
                if add_song.clicked() {
                    state.windows.toggle(&WindowId::NewPlaylist, true);
                }
            });
        });
        Ok(()) 
    }
}
