use std::str::FromStr;

use egui::{Sense, Vec2};
use xmpd_manifest::{playlist::{self, Playlist}, store::BaseStore};

use super::{Window, WindowId};


#[derive(Debug)]
pub struct NewPlaylistW {
    name: String,
    author: String,
}

impl Default for NewPlaylistW {
    fn default() -> Self {
        Self {
            name: String::from("New Playlist"),
            author: String::from("Unknown"),
        }
    }
}

impl Window for NewPlaylistW {
    fn id() -> WindowId where Self: Sized {
        WindowId::NewPlaylist
    }
    fn default_title() -> &'static str where Self: Sized {
        "New Playlist"
    }
    fn draw(&mut self, ui: &mut egui::Ui, state: &mut crate::GuiState) -> crate::Result<()> {
        let theme = xmpd_settings::Settings::get()?.theme.clone();
        let img_size = 64.0;
        let img_spacing = 10.0;
        ui.vertical(|ui| {
            ui.horizontal(|ui| {
                let mut rect = egui::Rect::ZERO;
                rect.set_width(img_size);
                rect.set_height(img_size);
                rect.set_top(img_spacing);
                rect.set_left(img_spacing);
                let rect_int = ui.interact(rect, "new_playlist_w".into(), Sense::click());
                if rect_int.hovered() {
                    ui.allocate_ui_at_rect(rect, |ui| {
                        ui.group(|ui| {
                            let img = egui::Image::new(crate::data::PLUS_ICON)
                                .tint(theme.accent_color)
                                .fit_to_exact_size(Vec2::new(img_size, img_size));
                                //.paint_at(ui, rect);
                            ui.add(img);
                        });
                    });
   
                } else {
                    ui.allocate_ui_at_rect(rect, |ui| {
                        ui.group(|ui| {
                            let img = egui::Image::new(crate::data::NOTE_ICON)
                                .tint(theme.accent_color)
                                .fit_to_exact_size(Vec2::new(img_size, img_size));
                                //.paint_at(ui, rect);
                            ui.add(img);
                        });
                    });
                }
                if rect_int.clicked() {
                    // TODO: Add a way to add custom icons
                }
                ui.vertical(|ui| {
                    ui.add_space(img_spacing);
                    ui.horizontal(|ui| { 
                        ui.label("Name:   ");
                        ui.text_edit_singleline(&mut self.name);
                    });
                    ui.horizontal(|ui| { 
                        ui.label("Author: ");
                        ui.text_edit_singleline(&mut self.author);
                    });
                });
            });
            ui.with_layout(egui::Layout::bottom_up(egui::Align::Max), |ui| {
                ui.add_space(3.0);
                ui.horizontal(|ui| {
                    ui.add_space(3.0);
                    if ui.button("Cancel").clicked() {
                        self.author = String::from("New Playlist");
                        self.name = String::from("Unknown");
                        state.windows.toggle(&WindowId::NewPlaylist, false);
                    }
                    if ui.button("Add").clicked() {
                        let mut playlist = Playlist::default();
                        playlist.set_name(&self.name);
                        playlist.set_author(&self.author);
                        let playlists = state.manifest.store_mut().get_playlists_mut();
                        playlists.insert(uuid::Uuid::new_v4(), playlist);
                        state.windows.toggle(&WindowId::NewPlaylist, false);
                    }
                });
            });
        });
        Ok(()) 
    }
}
