use uuid::Uuid;

use crate::{song::Song, store, Manifest};

use super::{Query, QueryType};

pub struct QueryPlaylist;

impl QueryType for QueryPlaylist {}

impl Query<QueryPlaylist> {
    pub fn id(&self) -> &Uuid {
        if let Some(id) = &self.playlist {
            return id;
        }
        unreachable!()
    }
    pub fn name<'a, ST: store::BaseStore + Clone>(&self, manifest: &'a Manifest<ST>) -> Option<&'a str> {
        let pl = manifest.store().get_playlist(self.id())?;
        Some(pl.name())
    }
    pub fn set_name<ST: store::BaseStore + Clone>(&self, manifest: &mut Manifest<ST>, name: &str) -> Option<()> {
        let pl = manifest.store_mut().get_playlist_mut(self.id())?;
        pl.set_name(name);
        Some(())
    }
    pub fn author<'a, ST: store::BaseStore + Clone>(&self, manifest: &'a Manifest<ST>) -> Option<&'a str> {
        let pl = manifest.store().get_playlist(self.id())?;
        Some(pl.author())
    }
    pub fn set_author<ST: store::BaseStore + Clone>(&self, manifest: &mut Manifest<ST>, author: &str) -> Option<()> {
        let pl = manifest.store_mut().get_playlist_mut(self.id())?;
        pl.set_author(author);
        Some(())
    }
    pub fn songs<'a, ST: store::BaseStore + Clone>(&self, manifest: &'a Manifest<ST>) -> Option<&'a Vec<Uuid>> {
        let pl = manifest.store().get_playlist(self.id())?;
        Some(pl.songs())
    }
    pub fn add_song<ST: store::BaseStore + Clone>(&self, manifest: &mut Manifest<ST>, song: Song) -> Option<Uuid> {
        let pl = manifest.store_mut().get_playlist_mut(self.id())?;
        let id = Uuid::new_v4();
        pl.add_song(&id);
        manifest.store_mut().get_songs_mut().insert(id, song);
        Some(id)
    }
}
